/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2020-2024. All rights reserved.
 */

#ifndef IMPL_TYPE_LIDARPOINTCLOUD_H
#define IMPL_TYPE_LIDARPOINTCLOUD_H

#include "impl_type_int64.h"
#include "impl_type_vectoruint8.h"
#include "impl_type_driverheader.h"

struct LidarPointCloud {
    ::Int64 width{ 0 };
    ::Int64 pointStep{ 0 };
    ::VectorUInt8 data;
    ::DriverHeader header;

    static bool IsPlane()
    {
        return false;
    }


    using IsEnumerableTag = void;
    template<typename F>
    void enumerate(F& fun)
    {
        fun(width);
        fun(pointStep);
        fun(data);
        fun(header);
    }

    template<typename F>
    void enumerate(F& fun) const
    {
        fun(width);
        fun(pointStep);
        fun(data);
        fun(header);
    }

    template<typename F>
    void enumerate_internal(F& fun)
    {
        fun("width", width);
        fun("pointStep", pointStep);
        fun("data", data);
        fun("header", header);
    }

    template<typename F>
    void enumerate_internal(F& fun) const
    {
        fun("width", width);
        fun("pointStep", pointStep);
        fun("data", data);
        fun("header", header);
    }

    friend bool operator==(const ::LidarPointCloud& lhs, const ::LidarPointCloud& rhs) noexcept
    {
        return (lhs.width == rhs.width) && (lhs.pointStep == rhs.pointStep) && (lhs.data == rhs.data) && (lhs.header == rhs.header);
    }
};


#endif // IMPL_TYPE_LIDARPOINTCLOUD_H
